/****************************************************************************
** Meta object code from reading C++ file 'todoview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../eventviews-26.07.90/src/todo/todoview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'todoview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10EventViews8TodoViewE_t {};
} // unnamed namespace

template <> constexpr inline auto EventViews::TodoView::qt_create_metaobjectdata<qt_meta_tag_ZN10EventViews8TodoViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EventViews::TodoView",
        "purgeCompletedSignal",
        "",
        "unSubTodoSignal",
        "unAllSubTodoSignal",
        "configChanged",
        "fullViewChanged",
        "printPreviewTodo",
        "printTodo",
        "createEvent",
        "Akonadi::Item",
        "setIncidenceChanger",
        "Akonadi::IncidenceChanger*",
        "changer",
        "showDates",
        "start",
        "end",
        "preferredMonth",
        "showIncidences",
        "Akonadi::Item::List",
        "incidenceList",
        "date",
        "updateView",
        "changeIncidenceDisplay",
        "incidence",
        "Akonadi::IncidenceChanger::ChangeType",
        "changeType",
        "updateConfig",
        "clearSelection",
        "expandIndex",
        "QModelIndex",
        "index",
        "restoreViewState",
        "saveViewState",
        "resizeEvent",
        "QResizeEvent*",
        "addQuickTodo",
        "Qt::KeyboardModifiers",
        "modifier",
        "contextMenu",
        "QPoint",
        "pos",
        "currentChanged",
        "current",
        "previous",
        "showTodo",
        "editTodo",
        "deleteTodo",
        "newTodo",
        "newSubTodo",
        "copyTodoToDate",
        "toggleTodoCompleted",
        "toggleTodoAlarm",
        "scheduleResizeColumns",
        "resizeColumns",
        "itemDoubleClicked",
        "setNewDate",
        "setStartDate",
        "setNewPercentage",
        "QAction*",
        "action",
        "setNewPriority",
        "changedCategories",
        "setFullView",
        "fullView",
        "setFlatView",
        "flatView",
        "notifyOtherViews",
        "onRowsInserted",
        "parent",
        "onTagsFetched",
        "KJob*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'purgeCompletedSignal'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'unSubTodoSignal'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'unAllSubTodoSignal'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fullViewChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'printPreviewTodo'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'printTodo'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'createEvent'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Slot 'setIncidenceChanger'
        QtMocHelpers::SlotData<void(Akonadi::IncidenceChanger *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'showDates'
        QtMocHelpers::SlotData<void(const QDate &, const QDate &, const QDate &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 15 }, { QMetaType::QDate, 16 }, { QMetaType::QDate, 17 },
        }}),
        // Slot 'showDates'
        QtMocHelpers::SlotData<void(const QDate &, const QDate &)>(14, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QDate, 15 }, { QMetaType::QDate, 16 },
        }}),
        // Slot 'showIncidences'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &, const QDate &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { QMetaType::QDate, 21 },
        }}),
        // Slot 'updateView'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'changeIncidenceDisplay'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, Akonadi::IncidenceChanger::ChangeType)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 24 }, { 0x80000000 | 25, 26 },
        }}),
        // Slot 'updateConfig'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearSelection'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'expandIndex'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'restoreViewState'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveViewState'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createEvent'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resizeEvent'
        QtMocHelpers::SlotData<void(QResizeEvent *)>(34, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 35, 2 },
        }}),
        // Slot 'addQuickTodo'
        QtMocHelpers::SlotData<void(Qt::KeyboardModifiers)>(36, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Slot 'contextMenu'
        QtMocHelpers::SlotData<void(QPoint)>(39, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 40, 41 },
        }}),
        // Slot 'currentChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(42, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 30, 43 }, { 0x80000000 | 30, 44 },
        }}),
        // Slot 'showTodo'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'editTodo'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'deleteTodo'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'newTodo'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'newSubTodo'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'copyTodoToDate'
        QtMocHelpers::SlotData<void(QDate)>(50, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QDate, 21 },
        }}),
        // Slot 'toggleTodoCompleted'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'toggleTodoAlarm'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'scheduleResizeColumns'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resizeColumns'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'itemDoubleClicked'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(55, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'setNewDate'
        QtMocHelpers::SlotData<void(QDate)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QDate, 21 },
        }}),
        // Slot 'setStartDate'
        QtMocHelpers::SlotData<void(QDate)>(57, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QDate, 21 },
        }}),
        // Slot 'setNewPercentage'
        QtMocHelpers::SlotData<void(QAction *)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 59, 60 },
        }}),
        // Slot 'setNewPriority'
        QtMocHelpers::SlotData<void(QAction *)>(61, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 59, 60 },
        }}),
        // Slot 'changedCategories'
        QtMocHelpers::SlotData<void(QAction *)>(62, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 59, 60 },
        }}),
        // Slot 'setFullView'
        QtMocHelpers::SlotData<void(bool)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 64 },
        }}),
        // Slot 'setFlatView'
        QtMocHelpers::SlotData<void(bool, bool)>(65, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 66 }, { QMetaType::Bool, 67 },
        }}),
        // Slot 'setFlatView'
        QtMocHelpers::SlotData<void(bool)>(65, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'onRowsInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 69 }, { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Slot 'onTagsFetched'
        QtMocHelpers::SlotData<void(KJob *)>(70, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 71, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TodoView, qt_meta_tag_ZN10EventViews8TodoViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EventViews::TodoView::staticMetaObject = { {
    QMetaObject::SuperData::link<EventViews::EventView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews8TodoViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews8TodoViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10EventViews8TodoViewE_t>.metaTypes,
    nullptr
} };

void EventViews::TodoView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TodoView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->purgeCompletedSignal(); break;
        case 1: _t->unSubTodoSignal(); break;
        case 2: _t->unAllSubTodoSignal(); break;
        case 3: _t->configChanged(); break;
        case 4: _t->fullViewChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->printPreviewTodo(); break;
        case 6: _t->printTodo(); break;
        case 7: _t->createEvent((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 8: _t->setIncidenceChanger((*reinterpret_cast<std::add_pointer_t<Akonadi::IncidenceChanger*>>(_a[1]))); break;
        case 9: _t->showDates((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[3]))); break;
        case 10: _t->showDates((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 11: _t->showIncidences((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 12: _t->updateView(); break;
        case 13: _t->changeIncidenceDisplay((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::IncidenceChanger::ChangeType>>(_a[2]))); break;
        case 14: _t->updateConfig(); break;
        case 15: _t->clearSelection(); break;
        case 16: _t->expandIndex((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 17: _t->restoreViewState(); break;
        case 18: _t->saveViewState(); break;
        case 19: _t->createEvent(); break;
        case 20: _t->resizeEvent((*reinterpret_cast<std::add_pointer_t<QResizeEvent*>>(_a[1]))); break;
        case 21: _t->addQuickTodo((*reinterpret_cast<std::add_pointer_t<Qt::KeyboardModifiers>>(_a[1]))); break;
        case 22: _t->contextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 23: _t->currentChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 24: _t->showTodo(); break;
        case 25: _t->editTodo(); break;
        case 26: _t->deleteTodo(); break;
        case 27: _t->newTodo(); break;
        case 28: _t->newSubTodo(); break;
        case 29: _t->copyTodoToDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 30: _t->toggleTodoCompleted(); break;
        case 31: _t->toggleTodoAlarm(); break;
        case 32: _t->scheduleResizeColumns(); break;
        case 33: _t->resizeColumns(); break;
        case 34: _t->itemDoubleClicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 35: _t->setNewDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 36: _t->setStartDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 37: _t->setNewPercentage((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 38: _t->setNewPriority((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 39: _t->changedCategories((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 40: _t->setFullView((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 41: _t->setFlatView((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 42: _t->setFlatView((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 43: _t->onRowsInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 44: _t->onTagsFetched((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::IncidenceChanger* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::IncidenceChanger::ChangeType >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 39:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 44:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TodoView::*)()>(_a, &TodoView::purgeCompletedSignal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TodoView::*)()>(_a, &TodoView::unSubTodoSignal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TodoView::*)()>(_a, &TodoView::unAllSubTodoSignal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TodoView::*)()>(_a, &TodoView::configChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TodoView::*)(bool )>(_a, &TodoView::fullViewChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TodoView::*)()>(_a, &TodoView::printPreviewTodo, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TodoView::*)()>(_a, &TodoView::printTodo, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TodoView::*)(const Akonadi::Item & )>(_a, &TodoView::createEvent, 7))
            return;
    }
}

const QMetaObject *EventViews::TodoView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::TodoView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews8TodoViewE_t>.strings))
        return static_cast<void*>(this);
    return EventViews::EventView::qt_metacast(_clname);
}

int EventViews::TodoView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = EventViews::EventView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    return _id;
}

// SIGNAL 0
void EventViews::TodoView::purgeCompletedSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void EventViews::TodoView::unSubTodoSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void EventViews::TodoView::unAllSubTodoSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void EventViews::TodoView::configChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void EventViews::TodoView::fullViewChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void EventViews::TodoView::printPreviewTodo()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void EventViews::TodoView::printTodo()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void EventViews::TodoView::createEvent(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
