/****************************************************************************
** Meta object code from reading C++ file 'agenda.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../eventviews-26.07.90/src/agenda/agenda.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'agenda.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10EventViews11MarcusBainsE_t {};
} // unnamed namespace

template <> constexpr inline auto EventViews::MarcusBains::qt_create_metaobjectdata<qt_meta_tag_ZN10EventViews11MarcusBainsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EventViews::MarcusBains",
        "updateLocation",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'updateLocation'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MarcusBains, qt_meta_tag_ZN10EventViews11MarcusBainsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EventViews::MarcusBains::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews11MarcusBainsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews11MarcusBainsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10EventViews11MarcusBainsE_t>.metaTypes,
    nullptr
} };

void EventViews::MarcusBains::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MarcusBains *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updateLocation(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *EventViews::MarcusBains::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::MarcusBains::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews11MarcusBainsE_t>.strings))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int EventViews::MarcusBains::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN10EventViews6AgendaE_t {};
} // unnamed namespace

template <> constexpr inline auto EventViews::Agenda::qt_create_metaobjectdata<qt_meta_tag_ZN10EventViews6AgendaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EventViews::Agenda",
        "newEventSignal",
        "",
        "newTimeSpanSignal",
        "QPoint",
        "newStartSelectSignal",
        "showIncidenceSignal",
        "KCalendarCore::Incidence::Ptr",
        "editIncidenceSignal",
        "deleteIncidenceSignal",
        "showIncidencePopupSignal",
        "showNewEventPopupSignal",
        "incidenceSelected",
        "lowerYChanged",
        "upperYChanged",
        "startDragSignal",
        "droppedIncidencesSignal",
        "KCalendarCore::Incidence::List",
        "droppedUrlsSignal",
        "QList<QUrl>",
        "enableAgendaUpdate",
        "zoomView",
        "Qt::Orientation",
        "mousePosSignal",
        "enterAgenda",
        "leaveAgenda",
        "gridSpacingYChanged",
        "scrollUp",
        "scrollDown",
        "checkScrollBoundaries",
        "deselectItem",
        "clearSelection",
        "selectItem",
        "EventViews::AgendaItem::QPtr",
        "selectIncidenceByUid",
        "id",
        "Akonadi::Item",
        "item",
        "removeAgendaItem",
        "showAgendaItem",
        "deleteItemsToDelete",
        "resizeAllContents"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newEventSignal'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newTimeSpanSignal'
        QtMocHelpers::SignalData<void(const QPoint &, const QPoint &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { 0x80000000 | 4, 2 },
        }}),
        // Signal 'newStartSelectSignal'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showIncidenceSignal'
        QtMocHelpers::SignalData<void(const KCalendarCore::Incidence::Ptr &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'editIncidenceSignal'
        QtMocHelpers::SignalData<void(const KCalendarCore::Incidence::Ptr &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'deleteIncidenceSignal'
        QtMocHelpers::SignalData<void(const KCalendarCore::Incidence::Ptr &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'showIncidencePopupSignal'
        QtMocHelpers::SignalData<void(const KCalendarCore::Incidence::Ptr &, const QDate &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Signal 'showNewEventPopupSignal'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'incidenceSelected'
        QtMocHelpers::SignalData<void(const KCalendarCore::Incidence::Ptr &, const QDate &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Signal 'lowerYChanged'
        QtMocHelpers::SignalData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'upperYChanged'
        QtMocHelpers::SignalData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'startDragSignal'
        QtMocHelpers::SignalData<void(const KCalendarCore::Incidence::Ptr &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'droppedIncidencesSignal'
        QtMocHelpers::SignalData<void(const KCalendarCore::Incidence::List &, const QPoint &, bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 2 }, { 0x80000000 | 4, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Signal 'droppedUrlsSignal'
        QtMocHelpers::SignalData<void(const QList<QUrl> &, const QPoint &, bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 2 }, { 0x80000000 | 4, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Signal 'enableAgendaUpdate'
        QtMocHelpers::SignalData<void(bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'zoomView'
        QtMocHelpers::SignalData<void(const int, const QPoint &, const Qt::Orientation)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { 0x80000000 | 4, 2 }, { 0x80000000 | 22, 2 },
        }}),
        // Signal 'mousePosSignal'
        QtMocHelpers::SignalData<void(const QPoint &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'enterAgenda'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'leaveAgenda'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gridSpacingYChanged'
        QtMocHelpers::SignalData<void(double)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'scrollUp'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'scrollDown'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'checkScrollBoundaries'
        QtMocHelpers::SlotData<void(int)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'deselectItem'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearSelection'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectItem'
        QtMocHelpers::SlotData<void(const EventViews::AgendaItem::QPtr &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 2 },
        }}),
        // Slot 'selectIncidenceByUid'
        QtMocHelpers::SlotData<void(const QString &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 35 },
        }}),
        // Slot 'selectItem'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Slot 'removeAgendaItem'
        QtMocHelpers::SlotData<bool(const EventViews::AgendaItem::QPtr &)>(38, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 33, 37 },
        }}),
        // Slot 'showAgendaItem'
        QtMocHelpers::SlotData<void(const EventViews::AgendaItem::QPtr &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 37 },
        }}),
        // Slot 'deleteItemsToDelete'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'resizeAllContents'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Agenda, qt_meta_tag_ZN10EventViews6AgendaE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EventViews::Agenda::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews6AgendaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews6AgendaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10EventViews6AgendaE_t>.metaTypes,
    nullptr
} };

void EventViews::Agenda::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Agenda *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newEventSignal(); break;
        case 1: _t->newTimeSpanSignal((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 2: _t->newStartSelectSignal(); break;
        case 3: _t->showIncidenceSignal((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[1]))); break;
        case 4: _t->editIncidenceSignal((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[1]))); break;
        case 5: _t->deleteIncidenceSignal((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[1]))); break;
        case 6: _t->showIncidencePopupSignal((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 7: _t->showNewEventPopupSignal(); break;
        case 8: _t->incidenceSelected((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 9: _t->lowerYChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->upperYChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->startDragSignal((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[1]))); break;
        case 12: _t->droppedIncidencesSignal((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 13: _t->droppedUrlsSignal((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 14: _t->enableAgendaUpdate((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->zoomView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::Orientation>>(_a[3]))); break;
        case 16: _t->mousePosSignal((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 17: _t->enterAgenda(); break;
        case 18: _t->leaveAgenda(); break;
        case 19: _t->gridSpacingYChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 20: _t->scrollUp(); break;
        case 21: _t->scrollDown(); break;
        case 22: _t->checkScrollBoundaries((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: _t->deselectItem(); break;
        case 24: _t->clearSelection(); break;
        case 25: _t->selectItem((*reinterpret_cast<std::add_pointer_t<EventViews::AgendaItem::QPtr>>(_a[1]))); break;
        case 26: _t->selectIncidenceByUid((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->selectItem((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 28: { bool _r = _t->removeAgendaItem((*reinterpret_cast<std::add_pointer_t<EventViews::AgendaItem::QPtr>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->showAgendaItem((*reinterpret_cast<std::add_pointer_t<EventViews::AgendaItem::QPtr>>(_a[1]))); break;
        case 30: _t->deleteItemsToDelete(); break;
        case 31: _t->resizeAllContents(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Agenda::*)()>(_a, &Agenda::newEventSignal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Agenda::*)(const QPoint & , const QPoint & )>(_a, &Agenda::newTimeSpanSignal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Agenda::*)()>(_a, &Agenda::newStartSelectSignal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Agenda::*)(const KCalendarCore::Incidence::Ptr & )>(_a, &Agenda::showIncidenceSignal, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Agenda::*)(const KCalendarCore::Incidence::Ptr & )>(_a, &Agenda::editIncidenceSignal, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Agenda::*)(const KCalendarCore::Incidence::Ptr & )>(_a, &Agenda::deleteIncidenceSignal, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Agenda::*)(const KCalendarCore::Incidence::Ptr & , const QDate & )>(_a, &Agenda::showIncidencePopupSignal, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Agenda::*)()>(_a, &Agenda::showNewEventPopupSignal, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Agenda::*)(const KCalendarCore::Incidence::Ptr & , const QDate & )>(_a, &Agenda::incidenceSelected, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Agenda::*)(int )>(_a, &Agenda::lowerYChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Agenda::*)(int )>(_a, &Agenda::upperYChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Agenda::*)(const KCalendarCore::Incidence::Ptr & )>(_a, &Agenda::startDragSignal, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Agenda::*)(const KCalendarCore::Incidence::List & , const QPoint & , bool )>(_a, &Agenda::droppedIncidencesSignal, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Agenda::*)(const QList<QUrl> & , const QPoint & , bool )>(_a, &Agenda::droppedUrlsSignal, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Agenda::*)(bool )>(_a, &Agenda::enableAgendaUpdate, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Agenda::*)(const int , const QPoint & , const Qt::Orientation )>(_a, &Agenda::zoomView, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Agenda::*)(const QPoint & )>(_a, &Agenda::mousePosSignal, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Agenda::*)()>(_a, &Agenda::enterAgenda, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Agenda::*)()>(_a, &Agenda::leaveAgenda, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Agenda::*)(double )>(_a, &Agenda::gridSpacingYChanged, 19))
            return;
    }
}

const QMetaObject *EventViews::Agenda::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::Agenda::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews6AgendaE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int EventViews::Agenda::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void EventViews::Agenda::newEventSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void EventViews::Agenda::newTimeSpanSignal(const QPoint & _t1, const QPoint & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void EventViews::Agenda::newStartSelectSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void EventViews::Agenda::showIncidenceSignal(const KCalendarCore::Incidence::Ptr & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void EventViews::Agenda::editIncidenceSignal(const KCalendarCore::Incidence::Ptr & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void EventViews::Agenda::deleteIncidenceSignal(const KCalendarCore::Incidence::Ptr & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void EventViews::Agenda::showIncidencePopupSignal(const KCalendarCore::Incidence::Ptr & _t1, const QDate & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void EventViews::Agenda::showNewEventPopupSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void EventViews::Agenda::incidenceSelected(const KCalendarCore::Incidence::Ptr & _t1, const QDate & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void EventViews::Agenda::lowerYChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void EventViews::Agenda::upperYChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void EventViews::Agenda::startDragSignal(const KCalendarCore::Incidence::Ptr & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void EventViews::Agenda::droppedIncidencesSignal(const KCalendarCore::Incidence::List & _t1, const QPoint & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2, _t3);
}

// SIGNAL 13
void EventViews::Agenda::droppedUrlsSignal(const QList<QUrl> & _t1, const QPoint & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2, _t3);
}

// SIGNAL 14
void EventViews::Agenda::enableAgendaUpdate(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void EventViews::Agenda::zoomView(const int _t1, const QPoint & _t2, const Qt::Orientation _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2, _t3);
}

// SIGNAL 16
void EventViews::Agenda::mousePosSignal(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void EventViews::Agenda::enterAgenda()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void EventViews::Agenda::leaveAgenda()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void EventViews::Agenda::gridSpacingYChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN10EventViews16AgendaScrollAreaE_t {};
} // unnamed namespace

template <> constexpr inline auto EventViews::AgendaScrollArea::qt_create_metaobjectdata<qt_meta_tag_ZN10EventViews16AgendaScrollAreaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EventViews::AgendaScrollArea"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AgendaScrollArea, qt_meta_tag_ZN10EventViews16AgendaScrollAreaE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EventViews::AgendaScrollArea::staticMetaObject = { {
    QMetaObject::SuperData::link<QScrollArea::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews16AgendaScrollAreaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews16AgendaScrollAreaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10EventViews16AgendaScrollAreaE_t>.metaTypes,
    nullptr
} };

void EventViews::AgendaScrollArea::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AgendaScrollArea *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *EventViews::AgendaScrollArea::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::AgendaScrollArea::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews16AgendaScrollAreaE_t>.strings))
        return static_cast<void*>(this);
    return QScrollArea::qt_metacast(_clname);
}

int EventViews::AgendaScrollArea::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QScrollArea::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
